@@ -121,6 +121,12 @@ const char *crypt_build_settings =
 #endif
 #if defined(LTC_CAMELLIA)
    "   Camellia\n"
+#endif
+#if defined(LTC_IDEA)
+   "   IDEA\n"
+#endif
+#if defined(LTC_SERPENT)
+   "   Serpent\n"
 #endif
    "Stream ciphers built-in:\n"
 #if defined(LTC_CHACHA)
